@@ -1,15 +1,13 @@
 package Project::Easy;
 
-# $Id: Easy.pm,v 1.1 2009/07/20 18:00:09 apla Exp $
+# $Id: Easy.pm,v 1.4 2009/03/02 02:59:06 apla Exp $
 
 use Class::Easy;
 use IO::Easy;
 
-use Project::Easy::Helper;
-
 use vars qw($VERSION);
 
-$VERSION = '0.09.01';
+$VERSION = '0.01';
 
 # because singletone
 our $instance = {};
@@ -21,22 +19,8 @@ sub instance {
 has 'daemons', default => {};
 
 has 'daemon_package', default => 'Project::Easy::Daemon';
-has 'db_package',     default => 'Project::Easy::DB';
-has 'conf_package',   default => 'Project::Easy::Config';
-
-has 'etc', default => 'etc';
-has 'bin', default => 'bin';
-
-sub import {
-	my $pack = shift;
-	my @params = @_;
-	
-	if (scalar grep {$_ eq 'script'} @params) {
-
-		($::pack, $::libs) = Project::Easy::Helper::_script_wrapper;
-		push @INC, @$::libs;
-	}
-}
+has 'db_package', default => 'Project::Easy::DB';
+has 'conf_package', default => 'Project::Easy::Config';
 
 sub init {
 	my $class = shift;
@@ -57,6 +41,7 @@ sub init {
 	my $db_package = $class->db_package;
 	try_to_use ($db_package);
 
+	
 	bless $instance, $class;
 	
 	$instance->{_initialized} = $class;
@@ -115,32 +100,24 @@ sub detect_environment {
 	make_accessor ($class, 'root', default => $root);
 
 	my $distro_path = $root->append ('var', 'distribution');
-	my $distro_string = $distro_path->as_file->contents;
+	my $distro = $distro_path->as_file->contents;
 	
-	chomp $distro_string;
-
-	die "can't recognise distribution '$distro_string'"
-		unless $distro_string;
+	chomp $distro;
 	
-	my ($distro, $fixup_core) = split (/:/, $distro_string, 2);
+	die "can't recognise distribution '$distro'"
+		unless $distro;
 	
 	make_accessor ($class, 'distro', default => $distro);
-	make_accessor ($class, 'fixup_core', default => $fixup_core);
 	
-	try_to_use ('Project::Easy::Config::File');
-	
-	my $conf_path = $root->append ($class->etc, $class->id . '.' . $class->conf_format)->as_file;
+	my $conf_path = $root->append ('etc', $class->id . '.' . $class->conf_format);
 	
 	die "can't locate generic config file at '$conf_path'"
 		unless -f $conf_path;
 	
-	# blessing for functionality extension: serializer
-	$conf_path = bless ($conf_path, 'Project::Easy::Config::File');
-	
 	make_accessor ($class, 'conf_path', default => $conf_path);
 	
-	my $fixup_path = $class->fixup_path_distro;
-
+	my $fixup_path = $root->append ('etc', $distro, $class->id . '.' . $class->conf_format);
+	
 	die "can't locate fixup config file at '$fixup_path'"
 		unless -f $fixup_path;
 	
@@ -148,26 +125,7 @@ sub detect_environment {
 	
 }
 
-sub fixup_path_distro {
-	my $self   = shift;
-	my $distro = shift || $self->distro;
-	
-	my $fixup_core = $self->fixup_core;
-	
-	my $fixup_path;
-	
-	if ($fixup_core) {
-		$fixup_path = IO::Easy->new ($fixup_core)->append ($distro);
-	} else {
-		$fixup_path = $self->root->append ($self->etc, $distro, $fixup_core);
-	}
-	
-	$fixup_path = $fixup_path->append ($self->id . '.' . $self->conf_format)->as_file;
-	
-	bless ($fixup_path, 'Project::Easy::Config::File');
-}
-
-sub daemon {
+sub get_daemon {
 	my $core = shift;
 	my $code = shift;
 	
@@ -177,12 +135,6 @@ sub daemon {
 sub config {
 	my $class = shift;
 	
-	if (@_ > 0) { # get config for another distro, do not cache
-		return $class->conf_package->parse (
-			$instance, @_
-		);
-	}
-	
 	unless ($instance->{config}) {
 		$instance->{config} = $class->conf_package->parse (
 			$instance
@@ -259,93 +211,11 @@ Project::Easy - project deployment made easy.
 
 	$class->init;
 
-=head1 ACCESSORS
-
-=head2 singleton
-
-=over 4
-
-=item instance
-
-return class instance
-
-=cut 
-
-=head2 configurable options
-
-=over 4
-
-=item id
-
-project id
-
-=item conf_format
-
-default config file format
-
-=item daemon_package
-
-interface for daemon creation
-
-default => 'Project::Easy::Daemon'
-
-=item db_package
-
-interface for db connections creation
-
-default => 'Project::Easy::DB'
-
-=item conf_package
-
-configuration interface
-
-default => 'Project::Easy::Config';
-
-=item default configuration directory
-
-has 'etc', default => 'etc';
-
-=item default binary directory
-
-has 'bin', default => 'bin';
-
-=cut
-
-=head2 autodetect options
-
-=over 4
-
-=item root
-
-IO::Easy object for project root directory
-
-=item distro
-
-string contains current distribution name
-
-=item fixup_core
-
-path (string) to configuration fixup root
-
-=item conf_path
-
-path object to the global configuration file
-
-=item fixup_path
-
-path object to the local configuration file
-
-=cut
-
 =head1 METHODS
 
-=head2 config
+=head2 new
 
-return configuration object
-
-=head2 db
-
-database pool
+TODO
 
 =cut
 
@@ -356,7 +226,7 @@ Ivan Baktsheev, C<< <apla at the-singlers.us> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to my email address,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Project-Easy>. 
+or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DBI-Easy>. 
 I will be notified, and then you'll automatically be notified
 of progress on your bug as I make changes.
 
